(function(){
  var fs, path, vows, assert, http, suite, sng;
  fs = require('fs');
  path = require('path');
  vows = require('vows');
  assert = require('assert');
  http = require('http');
  suite = vows.describe('La node-sng Test Suite');
  sng = require('../lib/sng');
  suite.addBatch({
    'Starting the Server': {
      topic: function(){
        sng.base(path.join(__dirname, './www/'));
        sng.start(this.callback);
      },
      'tmp-file created': function(err, res){
        return fs.stat(res.vars.tmpdir, function(err, stat){
          return assert.isTrue(stat.isDirectory());
        });
      },
      'php is running': function(err, res){
        return assert.isFalse(res.processes.php.killed);
      },
      'nginx is running': function(err, res){
        return assert.isFalse(res.processes.nginx.killed);
      },
      'tail access.log running': function(err, res){
        return assert.isFalse(res.processes.tail.killed);
      },
      'tail error.log running': function(err, res){
        return assert.isFalse(res.processes.err.killed);
      }
    }
  }).addBatch({
    'Testing the server': {
      topic: function(){
        var options, _this = this;
        options = {
          host: '127.0.0.1',
          port: 8000,
          path: '/index.html'
        };
        http.get(options, function(res){
          return _this.callback(null, res);
        });
      },
      'Making a request': function(e, res){
        return assert.equal(res.statusCode, 200);
      }
    }
  }).addBatch({
    'Stopping the server': {
      topic: function(){
        sng.stop(this.callback);
      },
      'tmp-file unlinked': function(err, res){
        return path.exists(res.vars.tmpdir, function(exists){
          return assert.isFalse(exists);
        });
      },
      'php is not running': function(err, res){
        return assert.isTrue(res.processes.php.killed);
      },
      'nginx is not running': function(err, res){
        return assert.isTrue(res.processes.nginx.killed);
      },
      'tail access.log is not running': function(err, res){
        return assert.isTrue(res.processes.tail.killed);
      },
      'tail error.log is not running': function(err, res){
        return assert.isTrue(res.processes.tail.killed);
      }
    }
  })['export'](module);
}).call(this);
